# coding: utf-8

"""
    Qdrant API

    API description for Qdrant vector search engine.  This document describes CRUD and search operations on collections of points (vectors with payload).  Qdrant supports any combinations of `should`, `must` and `must_not` conditions, which makes it possible to use in applications when object could not be described solely by vector. It could be location features, availability flags, and other custom properties businesses should take into account. ## Examples This examples cover the most basic use-cases - collection creation and basic vector search. ### Create collection First - let's create a collection with dot-production metric. ``` curl -X PUT 'http://localhost:6333/collections/test_collection' \\   -H 'Content-Type: application/json' \\   --data-raw '{     \"vectors\": {       \"size\": 4,       \"distance\": \"Dot\"     }   }'  ``` Expected response: ``` {     \"result\": true,     \"status\": \"ok\",     \"time\": 0.031095451 } ``` We can ensure that collection was created: ``` curl 'http://localhost:6333/collections/test_collection' ``` Expected response: ``` {   \"result\": {     \"status\": \"green\",     \"vectors_count\": 0,     \"segments_count\": 5,     \"disk_data_size\": 0,     \"ram_data_size\": 0,     \"config\": {       \"params\": {         \"vectors\": {           \"size\": 4,           \"distance\": \"Dot\"         }       },       \"hnsw_config\": {         \"m\": 16,         \"ef_construct\": 100,         \"full_scan_threshold\": 10000       },       \"optimizer_config\": {         \"deleted_threshold\": 0.2,         \"vacuum_min_vector_number\": 1000,         \"max_segment_number\": 5,         \"memmap_threshold\": 50000,         \"indexing_threshold\": 20000,         \"flush_interval_sec\": 1       },       \"wal_config\": {         \"wal_capacity_mb\": 32,         \"wal_segments_ahead\": 0       }     }   },   \"status\": \"ok\",   \"time\": 2.1199e-05 } ```  ### Add points Let's now add vectors with some payload: ``` curl -L -X PUT 'http://localhost:6333/collections/test_collection/points?wait=true' \\ -H 'Content-Type: application/json' \\ --data-raw '{   \"points\": [     {\"id\": 1, \"vector\": [0.05, 0.61, 0.76, 0.74], \"payload\": {\"city\": \"Berlin\"}},     {\"id\": 2, \"vector\": [0.19, 0.81, 0.75, 0.11], \"payload\": {\"city\": [\"Berlin\", \"London\"] }},     {\"id\": 3, \"vector\": [0.36, 0.55, 0.47, 0.94], \"payload\": {\"city\": [\"Berlin\", \"Moscow\"] }},     {\"id\": 4, \"vector\": [0.18, 0.01, 0.85, 0.80], \"payload\": {\"city\": [\"London\", \"Moscow\"] }},     {\"id\": 5, \"vector\": [0.24, 0.18, 0.22, 0.44], \"payload\": {\"count\": [0]}},     {\"id\": 6, \"vector\": [0.35, 0.08, 0.11, 0.44]}   ] }' ``` Expected response: ``` {     \"result\": {         \"operation_id\": 0,         \"status\": \"completed\"     },     \"status\": \"ok\",     \"time\": 0.000206061 } ``` ### Search with filtering Let's start with a basic request: ``` curl -L -X POST 'http://localhost:6333/collections/test_collection/points/search' \\ -H 'Content-Type: application/json' \\ --data-raw '{     \"vector\": [0.2,0.1,0.9,0.7],     \"top\": 3 }' ``` Expected response: ``` {     \"result\": [         { \"id\": 4, \"score\": 1.362, \"payload\": null, \"version\": 0 },         { \"id\": 1, \"score\": 1.273, \"payload\": null, \"version\": 0 },         { \"id\": 3, \"score\": 1.208, \"payload\": null, \"version\": 0 }     ],     \"status\": \"ok\",     \"time\": 0.000055785 } ``` But result is different if we add a filter: ``` curl -L -X POST 'http://localhost:6333/collections/test_collection/points/search' \\ -H 'Content-Type: application/json' \\ --data-raw '{     \"filter\": {         \"should\": [             {                 \"key\": \"city\",                 \"match\": {                     \"value\": \"London\"                 }             }         ]     },     \"vector\": [0.2, 0.1, 0.9, 0.7],     \"top\": 3 }' ``` Expected response: ``` {     \"result\": [         { \"id\": 4, \"score\": 1.362, \"payload\": null, \"version\": 0 },         { \"id\": 2, \"score\": 0.871, \"payload\": null, \"version\": 0 }     ],     \"status\": \"ok\",     \"time\": 0.000093972 } ``` 

    The version of the OpenAPI document: v1.7.x
    Contact: andrey@vasnetsov.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError

from typing_extensions import Annotated
from pydantic import Field, StrictBool, StrictBytes, StrictInt, StrictStr

from typing import Optional, Union

from qdrant_openapi.models.create_shard_key200_response import CreateShardKey200Response
from qdrant_openapi.models.create_snapshot200_response import CreateSnapshot200Response
from qdrant_openapi.models.list_snapshots200_response import ListSnapshots200Response
from qdrant_openapi.models.shard_snapshot_recover import ShardSnapshotRecover
from qdrant_openapi.models.snapshot_priority import SnapshotPriority
from qdrant_openapi.models.snapshot_recover import SnapshotRecover

from qdrant_openapi.api_client import ApiClient
from qdrant_openapi.api_response import ApiResponse
from qdrant_openapi.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class SnapshotsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    def create_full_snapshot(self, wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> CreateSnapshot200Response:  # noqa: E501
        """Create storage snapshot  # noqa: E501

        Create new snapshot of the whole storage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_full_snapshot(wait, async_req=True)
        >>> result = thread.get()

        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateSnapshot200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_full_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_full_snapshot_with_http_info(wait, **kwargs)  # noqa: E501

    @validate_arguments
    def create_full_snapshot_with_http_info(self, wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Create storage snapshot  # noqa: E501

        Create new snapshot of the whole storage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_full_snapshot_with_http_info(wait, async_req=True)
        >>> result = thread.get()

        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateSnapshot200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'wait'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_full_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateSnapshot200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/snapshots', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_shard_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection for which to create a snapshot")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> CreateSnapshot200Response:  # noqa: E501
        """Create shard snapshot  # noqa: E501

        Create new snapshot of a shard for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_shard_snapshot(collection_name, shard_id, wait, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection for which to create a snapshot (required)
        :type collection_name: str
        :param shard_id: Id of the shard (required)
        :type shard_id: int
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateSnapshot200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_shard_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_shard_snapshot_with_http_info(collection_name, shard_id, wait, **kwargs)  # noqa: E501

    @validate_arguments
    def create_shard_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection for which to create a snapshot")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Create shard snapshot  # noqa: E501

        Create new snapshot of a shard for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_shard_snapshot_with_http_info(collection_name, shard_id, wait, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection for which to create a snapshot (required)
        :type collection_name: str
        :param shard_id: Id of the shard (required)
        :type shard_id: int
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateSnapshot200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'shard_id',
            'wait'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_shard_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']

        if _params['shard_id'] is not None:
            _path_params['shard_id'] = _params['shard_id']


        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateSnapshot200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/shards/{shard_id}/snapshots', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def create_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection for which to create a snapshot")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> CreateSnapshot200Response:  # noqa: E501
        """Create collection snapshot  # noqa: E501

        Create new snapshot for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_snapshot(collection_name, wait, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection for which to create a snapshot (required)
        :type collection_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateSnapshot200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the create_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.create_snapshot_with_http_info(collection_name, wait, **kwargs)  # noqa: E501

    @validate_arguments
    def create_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection for which to create a snapshot")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Create collection snapshot  # noqa: E501

        Create new snapshot for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.create_snapshot_with_http_info(collection_name, wait, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection for which to create a snapshot (required)
        :type collection_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateSnapshot200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'wait'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']


        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateSnapshot200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/snapshots', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_full_snapshot(self, snapshot_name : Annotated[StrictStr, Field(..., description="Name of the full snapshot to delete")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> CreateShardKey200Response:  # noqa: E501
        """Delete storage snapshot  # noqa: E501

        Delete snapshot of the whole storage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_full_snapshot(snapshot_name, wait, async_req=True)
        >>> result = thread.get()

        :param snapshot_name: Name of the full snapshot to delete (required)
        :type snapshot_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateShardKey200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the delete_full_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.delete_full_snapshot_with_http_info(snapshot_name, wait, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_full_snapshot_with_http_info(self, snapshot_name : Annotated[StrictStr, Field(..., description="Name of the full snapshot to delete")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Delete storage snapshot  # noqa: E501

        Delete snapshot of the whole storage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_full_snapshot_with_http_info(snapshot_name, wait, async_req=True)
        >>> result = thread.get()

        :param snapshot_name: Name of the full snapshot to delete (required)
        :type snapshot_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateShardKey200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'snapshot_name',
            'wait'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_full_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['snapshot_name'] is not None:
            _path_params['snapshot_name'] = _params['snapshot_name']


        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateShardKey200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/snapshots/{snapshot_name}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_shard_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection for which to delete a snapshot")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard")], snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to delete")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> CreateShardKey200Response:  # noqa: E501
        """Delete shard snapshot  # noqa: E501

        Delete snapshot of a shard for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_shard_snapshot(collection_name, shard_id, snapshot_name, wait, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection for which to delete a snapshot (required)
        :type collection_name: str
        :param shard_id: Id of the shard (required)
        :type shard_id: int
        :param snapshot_name: Name of the snapshot to delete (required)
        :type snapshot_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateShardKey200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the delete_shard_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.delete_shard_snapshot_with_http_info(collection_name, shard_id, snapshot_name, wait, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_shard_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection for which to delete a snapshot")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard")], snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to delete")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Delete shard snapshot  # noqa: E501

        Delete snapshot of a shard for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_shard_snapshot_with_http_info(collection_name, shard_id, snapshot_name, wait, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection for which to delete a snapshot (required)
        :type collection_name: str
        :param shard_id: Id of the shard (required)
        :type shard_id: int
        :param snapshot_name: Name of the snapshot to delete (required)
        :type snapshot_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateShardKey200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'shard_id',
            'snapshot_name',
            'wait'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_shard_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']

        if _params['shard_id'] is not None:
            _path_params['shard_id'] = _params['shard_id']

        if _params['snapshot_name'] is not None:
            _path_params['snapshot_name'] = _params['snapshot_name']


        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateShardKey200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/shards/{shard_id}/snapshots/{snapshot_name}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def delete_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection for which to delete a snapshot")], snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to delete")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> CreateShardKey200Response:  # noqa: E501
        """Delete collection snapshot  # noqa: E501

        Delete snapshot for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_snapshot(collection_name, snapshot_name, wait, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection for which to delete a snapshot (required)
        :type collection_name: str
        :param snapshot_name: Name of the snapshot to delete (required)
        :type snapshot_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateShardKey200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the delete_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.delete_snapshot_with_http_info(collection_name, snapshot_name, wait, **kwargs)  # noqa: E501

    @validate_arguments
    def delete_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection for which to delete a snapshot")], snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to delete")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Delete collection snapshot  # noqa: E501

        Delete snapshot for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.delete_snapshot_with_http_info(collection_name, snapshot_name, wait, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection for which to delete a snapshot (required)
        :type collection_name: str
        :param snapshot_name: Name of the snapshot to delete (required)
        :type snapshot_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateShardKey200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'snapshot_name',
            'wait'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']

        if _params['snapshot_name'] is not None:
            _path_params['snapshot_name'] = _params['snapshot_name']


        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateShardKey200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/snapshots/{snapshot_name}', 'DELETE',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_full_snapshot(self, snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to download")], **kwargs) -> bytearray:  # noqa: E501
        """Download storage snapshot  # noqa: E501

        Download specified snapshot of the whole storage as a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_full_snapshot(snapshot_name, async_req=True)
        >>> result = thread.get()

        :param snapshot_name: Name of the snapshot to download (required)
        :type snapshot_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: bytearray
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_full_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_full_snapshot_with_http_info(snapshot_name, **kwargs)  # noqa: E501

    @validate_arguments
    def get_full_snapshot_with_http_info(self, snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to download")], **kwargs) -> ApiResponse:  # noqa: E501
        """Download storage snapshot  # noqa: E501

        Download specified snapshot of the whole storage as a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_full_snapshot_with_http_info(snapshot_name, async_req=True)
        >>> result = thread.get()

        :param snapshot_name: Name of the snapshot to download (required)
        :type snapshot_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(bytearray, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'snapshot_name'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_full_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['snapshot_name'] is not None:
            _path_params['snapshot_name'] = _params['snapshot_name']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "bytearray",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/snapshots/{snapshot_name}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_shard_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard")], snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to download")], **kwargs) -> bytearray:  # noqa: E501
        """Download collection snapshot  # noqa: E501

        Download specified snapshot of a shard from a collection as a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_shard_snapshot(collection_name, shard_id, snapshot_name, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param shard_id: Id of the shard (required)
        :type shard_id: int
        :param snapshot_name: Name of the snapshot to download (required)
        :type snapshot_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: bytearray
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_shard_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_shard_snapshot_with_http_info(collection_name, shard_id, snapshot_name, **kwargs)  # noqa: E501

    @validate_arguments
    def get_shard_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard")], snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to download")], **kwargs) -> ApiResponse:  # noqa: E501
        """Download collection snapshot  # noqa: E501

        Download specified snapshot of a shard from a collection as a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_shard_snapshot_with_http_info(collection_name, shard_id, snapshot_name, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param shard_id: Id of the shard (required)
        :type shard_id: int
        :param snapshot_name: Name of the snapshot to download (required)
        :type snapshot_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(bytearray, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'shard_id',
            'snapshot_name'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_shard_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']

        if _params['shard_id'] is not None:
            _path_params['shard_id'] = _params['shard_id']

        if _params['snapshot_name'] is not None:
            _path_params['snapshot_name'] = _params['snapshot_name']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "bytearray",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/shards/{shard_id}/snapshots/{snapshot_name}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def get_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to download")], **kwargs) -> bytearray:  # noqa: E501
        """Download collection snapshot  # noqa: E501

        Download specified snapshot from a collection as a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_snapshot(collection_name, snapshot_name, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param snapshot_name: Name of the snapshot to download (required)
        :type snapshot_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: bytearray
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the get_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.get_snapshot_with_http_info(collection_name, snapshot_name, **kwargs)  # noqa: E501

    @validate_arguments
    def get_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], snapshot_name : Annotated[StrictStr, Field(..., description="Name of the snapshot to download")], **kwargs) -> ApiResponse:  # noqa: E501
        """Download collection snapshot  # noqa: E501

        Download specified snapshot from a collection as a file  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.get_snapshot_with_http_info(collection_name, snapshot_name, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param snapshot_name: Name of the snapshot to download (required)
        :type snapshot_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(bytearray, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'snapshot_name'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']

        if _params['snapshot_name'] is not None:
            _path_params['snapshot_name'] = _params['snapshot_name']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/octet-stream'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "bytearray",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/snapshots/{snapshot_name}', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_full_snapshots(self, **kwargs) -> ListSnapshots200Response:  # noqa: E501
        """List of storage snapshots  # noqa: E501

        Get list of snapshots of the whole storage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_full_snapshots(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListSnapshots200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the list_full_snapshots_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.list_full_snapshots_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    def list_full_snapshots_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """List of storage snapshots  # noqa: E501

        Get list of snapshots of the whole storage  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_full_snapshots_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListSnapshots200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_full_snapshots" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "ListSnapshots200Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/snapshots', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_shard_snapshots(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard")], **kwargs) -> ListSnapshots200Response:  # noqa: E501
        """List shards snapshots for a collection  # noqa: E501

        Get list of snapshots for a shard of a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_shard_snapshots(collection_name, shard_id, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param shard_id: Id of the shard (required)
        :type shard_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListSnapshots200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the list_shard_snapshots_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.list_shard_snapshots_with_http_info(collection_name, shard_id, **kwargs)  # noqa: E501

    @validate_arguments
    def list_shard_snapshots_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard")], **kwargs) -> ApiResponse:  # noqa: E501
        """List shards snapshots for a collection  # noqa: E501

        Get list of snapshots for a shard of a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_shard_snapshots_with_http_info(collection_name, shard_id, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param shard_id: Id of the shard (required)
        :type shard_id: int
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListSnapshots200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'shard_id'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_shard_snapshots" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']

        if _params['shard_id'] is not None:
            _path_params['shard_id'] = _params['shard_id']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "ListSnapshots200Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/shards/{shard_id}/snapshots', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def list_snapshots(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], **kwargs) -> ListSnapshots200Response:  # noqa: E501
        """List collection snapshots  # noqa: E501

        Get list of snapshots for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_snapshots(collection_name, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ListSnapshots200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the list_snapshots_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.list_snapshots_with_http_info(collection_name, **kwargs)  # noqa: E501

    @validate_arguments
    def list_snapshots_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], **kwargs) -> ApiResponse:  # noqa: E501
        """List collection snapshots  # noqa: E501

        Get list of snapshots for a collection  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.list_snapshots_with_http_info(collection_name, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ListSnapshots200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_snapshots" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']


        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "ListSnapshots200Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/snapshots', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def recover_from_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, snapshot_recover : Annotated[Optional[SnapshotRecover], Field(description="Snapshot to recover from")] = None, **kwargs) -> CreateShardKey200Response:  # noqa: E501
        """Recover from a snapshot  # noqa: E501

        Recover local collection data from a snapshot. This will overwrite any data, stored on this node, for the collection. If collection does not exist - it will be created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recover_from_snapshot(collection_name, wait, snapshot_recover, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param snapshot_recover: Snapshot to recover from
        :type snapshot_recover: SnapshotRecover
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateShardKey200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the recover_from_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.recover_from_snapshot_with_http_info(collection_name, wait, snapshot_recover, **kwargs)  # noqa: E501

    @validate_arguments
    def recover_from_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, snapshot_recover : Annotated[Optional[SnapshotRecover], Field(description="Snapshot to recover from")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Recover from a snapshot  # noqa: E501

        Recover local collection data from a snapshot. This will overwrite any data, stored on this node, for the collection. If collection does not exist - it will be created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recover_from_snapshot_with_http_info(collection_name, wait, snapshot_recover, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param snapshot_recover: Snapshot to recover from
        :type snapshot_recover: SnapshotRecover
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateShardKey200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'wait',
            'snapshot_recover'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recover_from_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']


        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['snapshot_recover'] is not None:
            _body_params = _params['snapshot_recover']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateShardKey200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/snapshots/recover', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def recover_from_uploaded_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, priority : Annotated[Optional[SnapshotPriority], Field(description="Defines source of truth for snapshot recovery")] = None, snapshot : Optional[Union[StrictBytes, StrictStr]] = None, **kwargs) -> CreateShardKey200Response:  # noqa: E501
        """Recover from an uploaded snapshot  # noqa: E501

        Recover local collection data from an uploaded snapshot. This will overwrite any data, stored on this node, for the collection. If collection does not exist - it will be created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recover_from_uploaded_snapshot(collection_name, wait, priority, snapshot, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param priority: Defines source of truth for snapshot recovery
        :type priority: SnapshotPriority
        :param snapshot:
        :type snapshot: bytearray
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateShardKey200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the recover_from_uploaded_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.recover_from_uploaded_snapshot_with_http_info(collection_name, wait, priority, snapshot, **kwargs)  # noqa: E501

    @validate_arguments
    def recover_from_uploaded_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, priority : Annotated[Optional[SnapshotPriority], Field(description="Defines source of truth for snapshot recovery")] = None, snapshot : Optional[Union[StrictBytes, StrictStr]] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Recover from an uploaded snapshot  # noqa: E501

        Recover local collection data from an uploaded snapshot. This will overwrite any data, stored on this node, for the collection. If collection does not exist - it will be created.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recover_from_uploaded_snapshot_with_http_info(collection_name, wait, priority, snapshot, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param priority: Defines source of truth for snapshot recovery
        :type priority: SnapshotPriority
        :param snapshot:
        :type snapshot: bytearray
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateShardKey200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'wait',
            'priority',
            'snapshot'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recover_from_uploaded_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']


        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        if _params.get('priority') is not None:  # noqa: E501
            _query_params.append(('priority', _params['priority'].value))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        if _params['snapshot'] is not None:
            _files['snapshot'] = _params['snapshot']

        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateShardKey200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/snapshots/upload', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def recover_shard_from_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard to recover")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, shard_snapshot_recover : Annotated[Optional[ShardSnapshotRecover], Field(description="Snapshot to recover from")] = None, **kwargs) -> CreateShardKey200Response:  # noqa: E501
        """Recover from a snapshot  # noqa: E501

        Recover shard of a local collection data from a snapshot. This will overwrite any data, stored in this shard, for the collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recover_shard_from_snapshot(collection_name, shard_id, wait, shard_snapshot_recover, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param shard_id: Id of the shard to recover (required)
        :type shard_id: int
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param shard_snapshot_recover: Snapshot to recover from
        :type shard_snapshot_recover: ShardSnapshotRecover
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateShardKey200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the recover_shard_from_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.recover_shard_from_snapshot_with_http_info(collection_name, shard_id, wait, shard_snapshot_recover, **kwargs)  # noqa: E501

    @validate_arguments
    def recover_shard_from_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard to recover")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, shard_snapshot_recover : Annotated[Optional[ShardSnapshotRecover], Field(description="Snapshot to recover from")] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Recover from a snapshot  # noqa: E501

        Recover shard of a local collection data from a snapshot. This will overwrite any data, stored in this shard, for the collection.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recover_shard_from_snapshot_with_http_info(collection_name, shard_id, wait, shard_snapshot_recover, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param shard_id: Id of the shard to recover (required)
        :type shard_id: int
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param shard_snapshot_recover: Snapshot to recover from
        :type shard_snapshot_recover: ShardSnapshotRecover
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateShardKey200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'shard_id',
            'wait',
            'shard_snapshot_recover'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recover_shard_from_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']

        if _params['shard_id'] is not None:
            _path_params['shard_id'] = _params['shard_id']


        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['shard_snapshot_recover'] is not None:
            _body_params = _params['shard_snapshot_recover']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateShardKey200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/shards/{shard_id}/snapshots/recover', 'PUT',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    def recover_shard_from_uploaded_snapshot(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard to recover")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, priority : Annotated[Optional[SnapshotPriority], Field(description="Defines source of truth for snapshot recovery")] = None, snapshot : Optional[Union[StrictBytes, StrictStr]] = None, **kwargs) -> CreateShardKey200Response:  # noqa: E501
        """Recover shard from an uploaded snapshot  # noqa: E501

        Recover shard of a local collection from an uploaded snapshot. This will overwrite any data, stored on this node, for the collection shard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recover_shard_from_uploaded_snapshot(collection_name, shard_id, wait, priority, snapshot, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param shard_id: Id of the shard to recover (required)
        :type shard_id: int
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param priority: Defines source of truth for snapshot recovery
        :type priority: SnapshotPriority
        :param snapshot:
        :type snapshot: bytearray
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: CreateShardKey200Response
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the recover_shard_from_uploaded_snapshot_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return self.recover_shard_from_uploaded_snapshot_with_http_info(collection_name, shard_id, wait, priority, snapshot, **kwargs)  # noqa: E501

    @validate_arguments
    def recover_shard_from_uploaded_snapshot_with_http_info(self, collection_name : Annotated[StrictStr, Field(..., description="Name of the collection")], shard_id : Annotated[StrictInt, Field(..., description="Id of the shard to recover")], wait : Annotated[Optional[StrictBool], Field(description="If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.")] = None, priority : Annotated[Optional[SnapshotPriority], Field(description="Defines source of truth for snapshot recovery")] = None, snapshot : Optional[Union[StrictBytes, StrictStr]] = None, **kwargs) -> ApiResponse:  # noqa: E501
        """Recover shard from an uploaded snapshot  # noqa: E501

        Recover shard of a local collection from an uploaded snapshot. This will overwrite any data, stored on this node, for the collection shard.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.recover_shard_from_uploaded_snapshot_with_http_info(collection_name, shard_id, wait, priority, snapshot, async_req=True)
        >>> result = thread.get()

        :param collection_name: Name of the collection (required)
        :type collection_name: str
        :param shard_id: Id of the shard to recover (required)
        :type shard_id: int
        :param wait: If true, wait for changes to actually happen. If false - let changes happen in background. Default is true.
        :type wait: bool
        :param priority: Defines source of truth for snapshot recovery
        :type priority: SnapshotPriority
        :param snapshot:
        :type snapshot: bytearray
        :param async_req: Whether to execute the request asynchronously.
        :type async_req: bool, optional
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(CreateShardKey200Response, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'collection_name',
            'shard_id',
            'wait',
            'priority',
            'snapshot'
        ]
        _all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method recover_shard_from_uploaded_snapshot" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}
        if _params['collection_name'] is not None:
            _path_params['collection_name'] = _params['collection_name']

        if _params['shard_id'] is not None:
            _path_params['shard_id'] = _params['shard_id']


        # process the query parameters
        _query_params = []
        if _params.get('wait') is not None:  # noqa: E501
            _query_params.append(('wait', _params['wait']))

        if _params.get('priority') is not None:  # noqa: E501
            _query_params.append(('priority', _params['priority'].value))

        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        if _params['snapshot'] is not None:
            _files['snapshot'] = _params['snapshot']

        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['api-key', 'bearerAuth']  # noqa: E501

        _response_types_map = {
            '200': "CreateShardKey200Response",
            '202': "RecoverFromUploadedSnapshot202Response",
            '4XX': "ErrorResponse",
        }

        return self.api_client.call_api(
            '/collections/{collection_name}/shards/{shard_id}/snapshots/upload', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            async_req=_params.get('async_req'),
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))
